import platform
import os
from pystyle import *
from replit import web
from flask import Flask, render_template, request
from flask_restful import Api, Resource

meoaw_x = Flask(__name__)
meoaw = Api(meoaw_x)

meoaw.run(host='0.0.0.0', port=8080)

class connect:

    web.run(meoaw_x)

@meoaw.route('/')
def main():

    text = "[ ✅ ]"

    connect = "Connected"

    if platform.system() == 'Windows':

        os.system('cls & title GOTji API ( Beta )')

        print(" ")

        print(" ")

        print(Colorate.Color(Colors.blue, text, True) + " " + " " + Colorate.Color(Colors.green, connect, True))

        print(" ")

        print(" ")

    else:

        os.system('clear')

        print(" ")

        print(" ")

        print(Colorate.Color(Colors.blue, text, True) + " " + " " + Colorate.Color(Colors.green, connect, True))

        print(" ")

        print(" ")



from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="gotji",
    version="1.0.6",
    description="Dev by Meoaw",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/exaDev99/gotji",
    author="exaDev99",
    author_email="meoawdev.me@gmail.com",
    license="MIT",
    packages=["gotji"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "requests",
        "pystyle",
        "platform",
        "os",
        "replit",
        "flask",
        "flask_restful"
    ],
)
